# Generated by roxygen2: do not edit by hand

S3method(autoplot,xi_acf)
S3method(autoplot,xi_ccf)
S3method(autoplot,xi_matrix)
S3method(print,xi_acf)
S3method(print,xi_ccf)
S3method(print,xi_matrix)
export(autoplot)
export(compute_xi_acf_iaaft)
export(compute_xi_acf_maxstat_cpp)
export(compute_xi_ccf_maxstat_cpp)
export(compute_xi_ccf_miaaft)
export(compute_xi_matrix_maxstat_cpp)
export(compute_xi_matrix_miaaft)
export(extract_xi_acf)
export(extract_xi_ccf)
export(generate_iaaft_surrogate)
export(generate_miaaft_surrogate_cpp)
export(generate_miaaft_surrogates)
export(run_rolling_xi_acf)
export(run_rolling_xi_analysis)
export(run_rolling_xi_ccf)
export(surrogate_iaaft_cpp)
export(surrogate_miaaft_cpp)
export(xi_acf)
export(xi_ccf)
export(xi_coefficient)
export(xi_matrix)
export(xi_test)
importFrom(Rcpp,evalCpp)
importFrom(doFuture,"%dofuture%")
importFrom(doFuture,registerDoFuture)
importFrom(dplyr,bind_rows)
importFrom(foreach,foreach)
importFrom(future,multisession)
importFrom(future,plan)
importFrom(future,sequential)
importFrom(ggplot2,aes)
importFrom(ggplot2,autoplot)
importFrom(ggplot2,coord_cartesian)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_rect)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_ribbon)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,guide_legend)
importFrom(ggplot2,guides)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,scale_fill_manual)
importFrom(ggplot2,scale_size_manual)
importFrom(ggplot2,scale_x_continuous)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_minimal)
importFrom(parallelly,availableCores)
importFrom(patchwork,plot_annotation)
importFrom(patchwork,wrap_plots)
importFrom(progressr,progressor)
importFrom(progressr,with_progress)
importFrom(stats,quantile)
importFrom(stats,var)
importFrom(utils,head)
useDynLib(xiacf, .registration = TRUE)
