# R/globals.R

utils::globalVariables(c(
    "Global_Threshold",
    "Lead_Var",
    "Lag_Var",
    "Significant",
    "ACF",
    "CCF",
    "Xi",
    "Lag",
    "i",
    "zero_line",
    "Label",
    "Pathway"
))
