% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/autoplot.xi_ccf.R
\name{autoplot.xi_ccf}
\alias{autoplot.xi_ccf}
\title{Plot Directional Xi-CCF Comparison}
\usage{
\method{autoplot}{xi_ccf}(object, ...)
}
\arguments{
\item{object}{An object of class \code{"xi_ccf"}.}

\item{...}{Additional arguments passed to other methods.}
}
\value{
A \code{ggplot} object representing the directional cross-correlogram.
}
\description{
Visualizes the comparison between the standard linear Cross-Correlation Function (CCF)
and the non-linear Chatterjee's Xi cross-correlation across two directions (X leads Y, Y leads X).
}
